pub struct ChannelDto {
pub id: u32,
pub name: String,
pub gain: f32,
pub tone_stack: ToneStackDto,
pub volume: f32,
pub effect_chain: Vec<EffectDto>,
}Expand description
Data transfer object for a Channel’s settings.
Fields
id: u32Unique identifier for the Channel.
name: StringName of the Channel
gain: f32The input gain level of the Channel.
tone_stack: ToneStackDtoThe tone stack settings, including bass, mid, treble of the Channel.
volume: f32The volume of the Channel.
effect_chain: Vec<EffectDto>The chain of effects the signal is sent through