MockAudioHandlerTrait

Struct MockAudioHandlerTrait 

pub struct MockAudioHandlerTrait { /* private fields */ }
Abstraction over the audio I/O handler used by AudioService.

Using the MockAudioHandlerTrait generated by mockall allows the audio pipeline to be tested without real hardware.

Implementations

Source

impl MockAudioHandlerTrait

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockAudioHandlerTrait

pub fn expect_build_input_stream(&mut self) -> &mut Expectation

Create an Expectation for mocking the build_input_stream method

pub fn expect_build_output_stream(&mut self) -> &mut Expectation

Create an Expectation for mocking the build_output_stream method

pub fn expect_input_device(&mut self) -> &mut Expectation

Create an Expectation for mocking the input_device method

pub fn expect_output_device(&mut self) -> &mut Expectation

Create an Expectation for mocking the output_device method

pub fn expect_input_config(&mut self) -> &mut Expectation

Create an Expectation for mocking the input_config method

pub fn expect_output_config(&mut self) -> &mut Expectation

Create an Expectation for mocking the output_config method

pub fn expect_input_sample_rate(&mut self) -> &mut Expectation

Create an Expectation for mocking the input_sample_rate method

pub fn expect_output_sample_rate(&mut self) -> &mut Expectation

Create an Expectation for mocking the output_sample_rate method