pub struct AudioHandler { /* private fields */ }Expand description
Concrete implementation of AudioHandlerTrait backed by real CPAL devices.
AudioHandler owns the input device, output device, and stream configuration
required to build CPAL streams. It is cheaply cloneable so that it can be
shared across threads via Arc.
Implementations
Sourceimpl AudioHandler
Auto-generated by derive_getters::Getters.
impl AudioHandler
Auto-generated by derive_getters::Getters.
Sourcepub fn input_device(&self) -> &Device
pub fn input_device(&self) -> &Device
Get field input_device from instance of AudioHandler.
Sourcepub fn output_device(&self) -> &Device
pub fn output_device(&self) -> &Device
Get field output_device from instance of AudioHandler.
Sourcepub fn input_config(&self) -> &StreamConfig
pub fn input_config(&self) -> &StreamConfig
Get field input_config from instance of AudioHandler.
Sourcepub fn output_config(&self) -> &StreamConfig
pub fn output_config(&self) -> &StreamConfig
Get field output_config from instance of AudioHandler.
Sourcepub fn input_sample_rate(&self) -> &u32
pub fn input_sample_rate(&self) -> &u32
Get field input_sample_rate from instance of AudioHandler.
Sourcepub fn output_sample_rate(&self) -> &u32
pub fn output_sample_rate(&self) -> &u32
Get field output_sample_rate from instance of AudioHandler.
Sourceimpl AudioHandler
impl AudioHandler
Sourcepub fn new(
input_device: Device,
output_device: Device,
input_config: StreamConfig,
output_config: StreamConfig,
) -> Self
pub fn new( input_device: Device, output_device: Device, input_config: StreamConfig, output_config: StreamConfig, ) -> Self
Creates a new AudioHandler with the given CPAL devices and stream config.
Arguments
input_device- The CPAL device used to capture audio.output_device- The CPAL device used to play back audio.input_config- The [StreamConfig] used for the input stream.output_config- The [StreamConfig] used for the output stream.
Sourcepub fn create_ringbuffer(size: usize) -> (HeapProd<f32>, HeapCons<f32>)
pub fn create_ringbuffer(size: usize) -> (HeapProd<f32>, HeapCons<f32>)
Creates a lock-free ring buffer of f32 samples with the given capacity.
Returns a (producer, consumer) pair that can be moved into separate
threads for wait-free, single-producer/single-consumer audio transfer.
Arguments
size- The number off32samples the ring buffer can hold.
Sourcepub fn set_output_device(&mut self, output_device: Device)
pub fn set_output_device(&mut self, output_device: Device)
Sourcepub fn set_input_device(&mut self, input_device: Device)
pub fn set_input_device(&mut self, input_device: Device)